==> scala-k8s-objects_sjs1_3-0.3.0-sources.jar: io/k8s/api/core/v1/Service.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** Service is a named abstraction of software service (for example, mysql) consisting of local port (for example 3306) that the proxy listens on, and the selector that determines which pods will answer requests sent through the proxy. */
final case class Service(
  status : Option[io.k8s.api.core.v1.ServiceStatus] = None,
  spec : Option[io.k8s.api.core.v1.ServiceSpec] = None,
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("", "Service", "v1")


  /** Returns a new data with status set to new value */
  def withStatus(value: io.k8s.api.core.v1.ServiceStatus) : Service = copy(status = Some(value))
  /** if status has a value, transforms to the result of function*/
  def mapStatus(f: io.k8s.api.core.v1.ServiceStatus => io.k8s.api.core.v1.ServiceStatus) : Service = copy(status = status.map(f))

  /** Returns a new data with spec set to new value */
  def withSpec(value: io.k8s.api.core.v1.ServiceSpec) : Service = copy(spec = Some(value))
  /** if spec has a value, transforms to the result of function*/
  def mapSpec(f: io.k8s.api.core.v1.ServiceSpec => io.k8s.api.core.v1.ServiceSpec) : Service = copy(spec = spec.map(f))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : Service = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : Service = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = Service.encoder[T].apply(this)
}

object Service {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.Service, T] = new Encoder[io.k8s.api.core.v1.Service, T] {
        def apply(o: io.k8s.api.core.v1.Service) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("status", o.status)
            .write("spec", o.spec)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, Service] = new Decoder[T, Service] {
      def apply(t: T): Either[String, Service] = for {
          obj <- ObjectReader(t)
          status <- obj.readOpt[io.k8s.api.core.v1.ServiceStatus]("status")
          spec <- obj.readOpt[io.k8s.api.core.v1.ServiceSpec]("spec")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta]("metadata")
      } yield Service (
          status = status,
          spec = spec,
          metadata = metadata
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.5.1-sources.jar: io/k8s/api/core/v1/Service.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** Service is a named abstraction of software service (for example, mysql) consisting of local port (for example 3306) that the proxy listens on, and the selector that determines which pods will answer requests sent through the proxy. */
final case class Service(
  status : Option[io.k8s.api.core.v1.ServiceStatus] = None,
  spec : Option[io.k8s.api.core.v1.ServiceSpec] = None,
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("", "Service", "v1")


  /** Returns a new data with status set to new value */
  def withStatus(value: io.k8s.api.core.v1.ServiceStatus) : Service = copy(status = Some(value))
  /** if status has a value, transforms to the result of function*/
  def mapStatus(f: io.k8s.api.core.v1.ServiceStatus => io.k8s.api.core.v1.ServiceStatus) : Service = copy(status = status.map(f))

  /** Returns a new data with spec set to new value */
  def withSpec(value: io.k8s.api.core.v1.ServiceSpec) : Service = copy(spec = Some(value))
  /** if spec has a value, transforms to the result of function*/
  def mapSpec(f: io.k8s.api.core.v1.ServiceSpec => io.k8s.api.core.v1.ServiceSpec) : Service = copy(spec = spec.map(f))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : Service = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : Service = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = Service.encoder.apply(this)
}

object Service {

    implicit val encoder : Encoder[io.k8s.api.core.v1.Service] = new Encoder[io.k8s.api.core.v1.Service] {
        def apply[T : Builder](o: io.k8s.api.core.v1.Service) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("status", o.status)
            .write("spec", o.spec)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit val decoder: Decoder[Service] = new Decoder[Service] {
      def apply[T : Reader](t: T): Either[String, Service] = for {
          obj <- ObjectReader(t)
          status <- obj.readOpt[io.k8s.api.core.v1.ServiceStatus]("status")
          spec <- obj.readOpt[io.k8s.api.core.v1.ServiceSpec]("spec")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta]("metadata")
      } yield Service (
          status = status,
          spec = spec,
          metadata = metadata
        )
    }
}
